<?php

namespace Drupal\hospital_price_transparency;

use Drupal\Core\Menu\MenuLinkDefault;
use Drupal\Core\Menu\StaticMenuLinkOverridesInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a menu link plugin for hospital_price_transparency.
 */
class HospitalPriceTransparencyMenuLink extends MenuLinkDefault {

  /**
   * Hospital Price Transparency service.
   *
   * @var \Drupal\hospital_price_transparency\HospitalPriceTransparencyService
   */
  protected $hospitalPriceTransparency;

  /**
   * Constructs a new HospitalPriceTransparencyMenuLink.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, StaticMenuLinkOverridesInterface $static_override, HospitalPriceTransparencyService $hospital_price_transparency) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $static_override);
    $this->hospitalPriceTransparency = $hospital_price_transparency;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('menu_link.static.overrides'),
      $container->get('hospital_price_transparency')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getRouteName() {
    if ($this->hospitalPriceTransparency->getFileUrl()) {
      return 'hospital_price_transparency.file';
    }
    else {
      return 'hospital_price_transparency.settings_form';
    }
  }

}
