<?php

namespace Drupal\hospital_price_transparency\PathProcessor;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\PathProcessor\InboundPathProcessorInterface;
use Drupal\Core\PathProcessor\OutboundPathProcessorInterface;
use Drupal\Core\Render\BubbleableMetadata;
use Symfony\Component\HttpFoundation\Request;

/**
 * A path processor for hospital_price_transparency.
 */
class HospitalPriceTransparencyPathProcessor implements OutboundPathProcessorInterface, InboundPathProcessorInterface {

  /**
   * Process configured path to use the hospital_price_transparency.file route.
   *
   * {@inheritdoc}
   */
  public function processInbound($path, Request $request = NULL) {
    $configured = \Drupal::configFactory()->get('hospital_price_transparency.settings')->get('path');
    if (($configured && $configured === $path)) {
      $path = '/hospital-price-transparency';
    }
    return $path;
  }

  /**
   * Process /hospital-price-transparency so it displays file path.
   *
   * {@inheritdoc}
   */
  public function processOutbound($path, &$options = [], Request $request = NULL, BubbleableMetadata $bubbleable_metadata = NULL) {
    $configured = \Drupal::configFactory()->get('hospital_price_transparency.settings')->get('path');
    if ($path === '/hospital-price-transparency' || ($configured && $configured === $path)) {
      if ($bubbleable_metadata) {
        $cacheability = new CacheableMetadata();
        $cacheability->addCacheTags(['config:hospital_price_transparency.settings']);
        $bubbleable_metadata->addCacheableDependency($cacheability);
      }
      $url = \Drupal::service('hospital_price_transparency')->getFileUrl();
      $path = $url ? $url->toString() : $path;
    }
    return $path;
  }

}
