<?php

namespace Drupal\Tests\hospital_price_transparency\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests hospital_price_transparency form.
 *
 * @group hospital_price_transparency
 */
class HospitalPriceTransparencyTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['hospital_price_transparency'];

  /**
   * {@inheritdoc}
   */
  public $defaultTheme = 'stark';

  /**
   * Use form to update config and confirm stylesheet is saved/updated.
   */
  public function testHospitalPriceTransparency() {
    $hpt = \Drupal::service('hospital_price_transparency');
    $this->assertFileDoesNotExist('public://123456789_Hospital_standardcharges.xml');
    $this->drupalLogin($this->drupalCreateUser(['administer hospital_price_transparency configuration']));

    // Go to the main route and expect a 404.
    $this->drupalGet('/hospital-price-transparency');
    $this->assertSession()->statusCodeEquals(404);
    $this->drupalGet('/my-custom-path');
    $this->assertSession()->statusCodeEquals(404);

    // Make sure we can call methods on the service even when there
    // is no file set, without getting exceptions.
    $this->assertNull($hpt->getFileUrl());
    $hpt->deletePriceTransparencyFile();

    // Save config for first time.
    $this->drupalGet('/admin/config/hospital-price-transparency');
    $real_path = \Drupal::service('file_system')->realpath(\Drupal::service('extension.list.module')->getPath('hospital_price_transparency') . "/tests/files/file.xml");
    $this->getSession()->getPage()->attachFileToField('files[file]', $real_path);
    $this->submitForm([
      'path' => '/my-custom-path',
      'ein' => '123456789',
      'hospital_name' => 'Hospital',
    ], 'Save configuration');

    $this->assertSession()->statusMessageContains('123456789_Hospital_standardcharges.xml was created');
    $this->assertFileExists('public://123456789_Hospital_standardcharges.xml');
    $this->drupalGet('/hospital-price-transparency');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->addressEquals($hpt->getFileUrl()->toString());
    $this->drupalGet('/my-custom-path');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->addressEquals($hpt->getFileUrl()->toString());

    // Update configs and see what happens.
    $this->drupalGet('/admin/config/hospital-price-transparency');
    $this->submitForm([
      'path' => '/my-second-path',
      'ein' => '987654321',
      'hospital_name' => 'Xray',
    ], 'Save configuration');

    $this->assertSession()->statusMessageContains('123456789_Hospital_standardcharges.xml was replaced by 987654321_Xray_standardcharges.xml');
    $this->assertFileDoesNotExist('public://123456789_Hospital_standardcharges.xml');
    $this->assertFileExists('public://987654321_Xray_standardcharges.xml');
    $this->drupalGet('/hospital-price-transparency');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->addressEquals($hpt->getFileUrl()->toString());
    $this->drupalGet('/my-custom-path');
    $this->assertSession()->statusCodeEquals(404);
    $this->drupalGet('/my-second-path');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->addressEquals($hpt->getFileUrl()->toString());

    // Update the file.
    $this->drupalGet('/admin/config/hospital-price-transparency');
    $real_path = \Drupal::service('file_system')->realpath(\Drupal::service('extension.list.module')->getPath('hospital_price_transparency') . "/tests/files/file.json");
    $this->getSession()->getPage()->attachFileToField('files[file]', $real_path);
    $this->submitForm([], 'Save configuration');

    $this->assertSession()->statusMessageContains('987654321_Xray_standardcharges.xml was replaced by 987654321_Xray_standardcharges.json');
    $this->assertFileDoesNotExist('public://987654321_Xray_standardcharges.xml');
    $this->assertFileExists('public://987654321_Xray_standardcharges.json');
    $this->drupalGet('/hospital-price-transparency');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->addressEquals($hpt->getFileUrl()->toString());
    $this->drupalGet('/my-second-path');
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->addressEquals($hpt->getFileUrl()->toString());

    // Uninstall and confirm the file is removed.
    \Drupal::service('module_installer')->uninstall(['hospital_price_transparency']);
    $this->assertFileDoesNotExist('public://987654321_Xray_standardcharges.json');
  }

}
